# python-optics-lab

## Установка

Устнавливем [Anaconda](https://www.anaconda.com/) для Python3 
или устанавливаем Python с [официального сайта](https://www.python.org/)

Устанавливаем пакет с помощью `pip`, для этого в терминале введите:
```
pip install mipt-npm-optics
```
Теперь можно заускать программу:
```
mipt-optics
```
или
```
mipt-optics.exe
```

### Ubuntu

#### Системный питон

```
sudo apt-get install python3-pip
```

### Установка зависимостей вручную
```
conda install pyqt numpy scipy matplotlib appdirs
```
или
```
pip3 install pyqt5 numpy scipy matplotlib appdirs
```